# URLs
TOKEN_URL = "https://cms.lamarzocco.io/oauth/v2/token"
CUSTOMER_URL = "https://cms.lamarzocco.io/api/customer"
GW_MACHINE_BASE_URL = "https://gw.lamarzocco.io/v1/home/machines"

POLLING_DELAY_S = 20

MODEL_LMU = "Micra"

# Key Names for Dictionaries
KEY = "key"
SERIAL_NUMBER = "serial_number"
MACHINE_NAME = "machine_name"
MODEL_NAME = "model_name"

# Dict keys are camel case for local API, all upper for remote API
MACHINE_MODE="MACHINEMODE"
STEAM_BOILER_NAME = "SteamBoiler"
COFFEE_BOILER_NAME = "CoffeeBoiler1"
BOILER_TARGET_TEMP = "BOILERTARGETTEMPERATURE"
BOILERS = "BOILERS"
PLUMBED_IN = "ISPLUMBEDIN"
PRE_INFUSION_SETTINGS = "PREINFUSIONSETTINGS"
WEEKLY_SCHEDULING_CONFIG = "WEEKLYSCHEDULINGCONFIG"
BACKFLUSH_ENABLED = "ISBACKFLUSHENABLED"
COFFEE_TEMP = "TEMP_COFFEE"
STEAM_TEMP = "TEMP_STEAM"
TANK_LEVEL = "LEVEL_TANK"
